@@ -1,9 +1,9 @@
 `WriteQC` <-
 function(filename, batch, x) {
 	
-	Xmed = median(log2(x[x[,3] == 23,1] / x[x[,3] == 23,2]), na.rm=TRUE)
-	dL = dLRs(log2(x[,1] / x[,2]))
-	l = log2(x[x[,3]<23,1] / x[x[,3]<23,2])
+	Xmed = median(x[x[,4] == 23,1], na.rm=TRUE)
+	dL = dLRs(x[order(x[,4], x[,5]),1])
+	l = x[x[,4]<23,1]
 	al = abs(l)
 	rp = quantile(al, 0.68, na.rm=TRUE)
 	qc = cbind(rp, dL, Xmed)
